@@ -4,6 +4,7 @@ import pytest
 from unittest import mock
 
 from python_anvil.api import Anvil, CreateEtchPacket
+from python_anvil.api_resources.payload import CreateEtchPacketPayload
 
 from ..api_resources.payload import FillPDFPayload
 from . import payloads
@@ -236,10 +237,34 @@ def describe_api():
         @mock.patch('python_anvil.api.GraphqlRequest.post')
         def test_create_etch_packet_json(m_request_post, m_create_unique, anvil):
             m_create_unique.return_value = "signer-mock-generated"
-            anvil.create_etch_packet(
-                json=json.dumps(payloads.EXPECTED_ETCH_TEST_PAYLOAD_JSON)
-            )
+            # We are currently removing `None`s from the payload, so do that here too.
+            payload = {
+                k: v
+                for k, v in payloads.EXPECTED_ETCH_TEST_PAYLOAD_JSON.items()
+                if v is not None
+            }
+            anvil.create_etch_packet(json=json.dumps(payload))
+            assert m_request_post.call_count == 1
+            assert payload in m_request_post.call_args[0]
+
+        @mock.patch(
+            'python_anvil.api_resources.mutations.create_etch_packet.create_unique_id'
+        )
+        @mock.patch('python_anvil.api.GraphqlRequest.post')
+        def test_adding_unsupported_fields(m_request_post, m_create_unique, anvil):
+            m_create_unique.return_value = "signer-mock-generated"
+            # We are currently removing `None`s from the payload, so do that here too.
+            payload = {
+                k: v
+                for k, v in payloads.EXPECTED_ETCH_TEST_PAYLOAD_JSON.items()
+                if v is not None
+            }
+            cep = CreateEtchPacketPayload.parse_obj(payload)
+            cep.newFeature = True
+            anvil.create_etch_packet(payload=cep)
             assert m_request_post.call_count == 1
             assert (
-                payloads.EXPECTED_ETCH_TEST_PAYLOAD_JSON in m_request_post.call_args[0]
+                cep.dict(by_alias=True, exclude_none=True)
+                == m_request_post.call_args[0][1]
             )
+            assert "newFeature" in m_request_post.call_args[0][1]
